###Label free quant NP dataset####

#Import packages
require(tidyverse)
require(scales)
require(ggplot2)
require(matrixStats)

#Set wd to any desired location on your PC
setwd("YOUR DIR")
getwd()

#2) import files and combine replicates (Protien level) and average individual injections
RX <- read.csv("2019_05_29 P1E17 Raw.csv", sep = ",", header = TRUE) #Output from PRIDE: PXD022555 or 10.6019/PXD022555"

#Take out proteins with 0 unique peptides
RX <- RX[!(RX$`Unique.peptides`==0),] 

#Select right columns 
RX <- RX %>% select(Accession, Peptide.count, Unique.peptides, Description:ncol(RX)) 

#Remove columns with double accession - separeted by ";"
RX <- RX[!grepl(";",RX$Accession),] 

#Calculate median across the injections
RX_calc <- RX %>% mutate(Median_1 = rowMedians(as.matrix(.[grep('X041719_CB_P1E17_II_1_\\d+_100ng', names(.))])),
                         Median_2 = rowMedians(as.matrix(.[grep('X041719_CB_P1E17_II_2_\\d+_100ng', names(.))])),
                         Median_3 = rowMedians(as.matrix(.[grep('X041719_CB_P1E17_II_3_\\d+_100ng', names(.))])),
                         Median_4 = rowMedians(as.matrix(.[grep('X041719_CB_P1E17_II_4_\\d+_100ng', names(.))])),
                         Median_5 = rowMedians(as.matrix(.[grep('X041719_CB_P1E17_II_5_\\d+_100ng', names(.))])),
                         Median_6 = rowMedians(as.matrix(.[grep('X041719_CB_P1E17_III_1_\\d+_100ng', names(.))])),
                         Median_7 = rowMedians(as.matrix(.[grep('X041719_CB_P1E17_III_2_\\d+_100ng', names(.))])),
                         Median_8 = rowMedians(as.matrix(.[grep('X041719_CB_P1E17_III_3_\\d+_100ng', names(.))])),
                         Median_9 = rowMedians(as.matrix(.[grep('X041719_CB_P1E17_III_4_\\d+_100ng', names(.))])),
                         Median_10 = rowMedians(as.matrix(.[grep('X041719_CB_P1E17_III_5_\\d+_100ng', names(.))])))

#Separate description into user-accesible columns
RX_f <- RX_calc %>% separate(Description, c("Full_Name", "Species", "Gene_Name_pre", "a", "b"), sep = "=", remove = FALSE
                             ) %>% separate(Gene_Name_pre, c("Gene_Name", "PE"), sep = "\\s")

#Reformat file to generate Master file 
RX_f <- RX_f[!is.na(RX_f$b),]
RX_f["Master"] <- paste(RX_f$Accession, RX_f$Gene_Name, sep = "_")
RX_f <- RX_f %>% select(Master, Accession, Gene_Name, Full_Name, Description, 
                        Species, Peptide.count, Unique.peptides, Median_1:Median_10,
                        X041719_CB_P1E17_II_1_1_100ng:X041719_CB_P1E17_III_5_5_100ng)

#Write Masterfile 
write.csv(RX_f, file = "P1E17_Masterfile.csv")

#Annotated agains Matrisome 
#Read Masterfile from line 49
MAfile <- read.csv("P1E17_Masterfile.csv", sep = ",", header = TRUE) %>% select(Master:X041719_CB_P1E17_III_5_5_100ng)

#Import the Matrisome dataset from the Matrisomeproject.org website (accessed in 06/2019)
Matrisome <- read.csv("matrisome_mm_masterlist.csv", sep = ",", header = TRUE) %>% select(Gene.Symbol, Division, Category)
names(Matrisome)[names(Matrisome) == 'Gene.Symbol'] <- 'Gene_Name'

#Annotate proteins 
MAfile_annotated <- merge(MAfile, Matrisome, by = "Gene_Name")

#Reformat the file and save the annotated masterfile 
MAfile_annotated <- with(MAfile_annotated, MAfile_annotated[order(MAfile_annotated$Category, MAfile_annotated$Division, MAfile_annotated$Gene_Name) , ])
write.csv(MAfile_annotated, file = "Masterfile_annotated_final.csv")


#Analyze KEGG annotations
#Read KEGG annotations as generated from DAVID 
E17_ECM_KEGG <- read.csv("2020_01_15 Masterlist KEGG.csv", header = TRUE, sep = ",")[read.csv("2020_01_15 Masterlist KEGG.csv", header = TRUE, sep = ",")$PValue <= 0.05
                                                                              & read.csv("2020_01_15 Masterlist KEGG.csv", header = TRUE, sep = ",")$Fold.Enrichment >= 1.5,
                                                                              ] %>% mutate(Log10_PValue = -log10(PValue),
                                                                                           Log10_FDR = -log10(FDR)
                                                                              ) %>% separate(Term, c("Term_NO","Term_Name"), sep = ":")




#Plot results in a barplot
ECM_p <- ggplot(E17_ECM_KEGG, aes(y = Log10_PValue, reorder(Term_Name, Log10_PValue))) +
  geom_bar(stat = "identity", color = "white", fill = "black", width = 1)+
  coord_flip()+
  theme_classic(base_size = 16)

#Save the plot 
aspect_ratio <- 1.5
ggsave("2) ECM_KEGG.pdf", plot = ECM_p, device = "pdf", height = 5* aspect_ratio , width = 7)
